==> recruit-drop-list-1.0.1.tgz: package/lib/listItem.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import React, { Component } from 'react';

var Radioitem =
/*#__PURE__*/
function (_Component) {
  _inherits(Radioitem, _Component);

  function Radioitem(props) {
    var _this;

    _classCallCheck(this, Radioitem);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Radioitem).call(this, props));
    _this.handelClick = _this.handelClick.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    return _this;
  }

  _createClass(Radioitem, [{
    key: "handelClick",
    value: function handelClick(event) {
      this.props.itemClick && this.props.itemClick(event, this.props.item);
    }
  }, {
    key: "render",
    value: function render() {
      var item = this.props.item;
      return React.createElement("li", {
        className: 'recruit-dropdown-item',
        onClick: this.handelClick
      }, React.createElement("span", {
        className: "recruit-dropdown-text d__name"
      }, item.text[0]), React.createElement("span", {
        className: "recruit-dropdown-text d__email"
      }, item.text[1]), React.createElement("span", {
        className: "recruit-dropdown-text d__apart"
      }, item.text[2]));
    }
  }]);

  return Radioitem;
}(Component);

export { Radioitem as default };

==> recruit-drop-list-1.0.12.tgz: package/lib/listItem.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import React, { Component } from 'react';
import ToolTip from '@beisen-platform/ethos/lib/ToolTip';

var Radioitem =
/*#__PURE__*/
function (_Component) {
  _inherits(Radioitem, _Component);

  function Radioitem(props) {
    var _this;

    _classCallCheck(this, Radioitem);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Radioitem).call(this, props));
    _this.handelClick = _this.handelClick.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    return _this;
  }

  _createClass(Radioitem, [{
    key: "handelClick",
    value: function handelClick(event) {
      this.props.itemClick && this.props.itemClick(event, this.props.item);
    }
  }, {
    key: "render",
    value: function render() {
      var item = this.props.item;
      return React.createElement("li", {
        className: 'recruit-dropdown-item',
        onClick: this.handelClick
      }, React.createElement(ToolTip, {
        title: item.text[0]
      }, React.createElement("span", {
        className: "recruit-dropdown-text d__name"
      }, item.text[0])), React.createElement(ToolTip, {
        title: item.text[1]
      }, React.createElement("span", {
        className: "recruit-dropdown-text d__email"
      }, item.text[1])), React.createElement(ToolTip, {
        title: item.text[2]
      }, React.createElement("span", {
        className: "recruit-dropdown-text d__apart"
      }, item.text[2])));
    }
  }]);

  return Radioitem;
}(Component);

export { Radioitem as default };
